use egui::{Color32, RichText, Vec2};
use xmpd_manifest::store::BaseStore;

use super::CompUi;


#[derive(Debug, Default)]
pub struct SongList;

component_register!(SongList);

impl CompUi for SongList {
    fn draw(ui: &mut egui::Ui, state: &mut crate::GuiState) -> crate::Result<()> {
        egui::ScrollArea::vertical().id_source("song_list").show(ui, |ui| {
            ui.vertical(|ui| {
                ui.add_space(3.0);
                let songs = state.manifest.store().get_songs();
                for (sid, song) in songs.iter() {
                    ui.horizontal(|ui| {
                        ui.add(
                            egui::Image::new(crate::data::NOTE_ICON)
                                .tint(crate::data::C_ACCENT)
                                .fit_to_exact_size(Vec2::new(32.0, 32.0))
                        );
                        ui.vertical(|ui| {
                            ui.label(song.name());
                            ui.monospace(
                                RichText::new(song.author())
                                    .color(crate::data::C_TEXT_DIM)
                                    .size(10.0)
                            );
                        });
                    });
                    ui.separator();
                }
            });
        });
        Ok(())
    }
}
